@@ -110,7 +110,7 @@ class Cache:
     on FastF1.
     """
     _CACHE_DIR = ''
-    _API_CORE_VERSION = 4  # version of the api parser code (unrelated to release version number)
+    _API_CORE_VERSION = 6  # version of the api parser code (unrelated to release version number)
     _IGNORE_VERSION = False
     _FORCE_RENEW = False
 
@@ -704,6 +704,19 @@ def _laps_data_driver(driver_raw, empty_vals, drv):
         # ensure that there is still data left after potentially removing a lap
         return drv_data
 
+    # check for incorrect lap times and remove them
+    # fixes GH#167 among others
+    for i in range(len(drv_data['Time'])):
+        sector_sum = datetime.timedelta(0)
+        for key in ('Sector1Time', 'Sector2Time', 'Sector3Time'):
+            st = drv_data[key][i]
+            if pd.isna(st):
+                continue
+            sector_sum += st
+        if sector_sum > drv_data['LapTime'][i]:
+            drv_data['LapTime'][i] = pd.NaT
+            integrity_errors.append(i+1)
+
     # lap time sync; check which sector time was triggered with the lowest latency
     # Sector3SessionTime == end of lap
     # Sector2SessionTime + Sector3Time == end of lap
@@ -1168,9 +1181,13 @@ def position_data(path, response=None, livedata=None):
             # instances in Session.load_telemetry
             # and except Status which should be 'OffTrack' for missing data
             index_df = pd.DataFrame(data={'Date': most_complete_ref})
-            data[driver] = data[driver].merge(index_df, how='outer').sort_values(by='Date').reset_index()
+            data[driver] = data[driver]\
+                .merge(index_df, how='outer')\
+                .sort_values(by='Date')\
+                .reset_index(drop=True)
             data[driver]['Status'].fillna(value='OffTrack', inplace=True)
-            data[driver].loc[:, ['X', 'Y', 'Z']] = data[driver].loc[:, ['X', 'Y', 'Z']].fillna(value=0, inplace=False)
+            data[driver].loc[:, ['X', 'Y', 'Z']] = data[driver]\
+                .loc[:, ['X', 'Y', 'Z']].fillna(value=0, inplace=False)
 
             logging.warning(f"Driver {driver: >2}: Position data is incomplete!")
 
@@ -1400,14 +1417,19 @@ def driver_info(path, response=None, livedata=None):
                 "recently, please try again in a few minutes."
             )
 
-    # search for the correct entries that contain driver and team info
+    # search for the correct entries that contain driver/team/headshot info
+    # for some sessions headshots are one entry for each team (Miami 22 FPs, Q)
     drv_idx = None
     team_idx = None
+    headshots = []
+
     for i, entry in enumerate(response):
         if 'RacingNumber' in str(entry):
             drv_idx = i
         if 'TeamName' in str(entry):
             team_idx = i
+        if 'HeadshotUrl' in str(entry):
+            headshots.append(i)
         if drv_idx and team_idx:
             break
 
@@ -1421,9 +1443,20 @@ def driver_info(path, response=None, livedata=None):
         team_info = response[team_idx][1]
     except (IndexError, TypeError):
         return dict()
+
+    # loop through headshots
+    try:
+        head_info = dict()
+        for head in headshots:
+            head_info.update(response[head][1])
+    except (IndexError, TypeError):
+        return dict()
+
     else:
         for drv in drv_info:
             drv_info[drv].update(team_info.get(drv, {}))
+            drv_info[drv].update(head_info.get(drv, {}))
+
         if not len(drv_info) or not isinstance(drv_info, dict):
             return dict()
         if 'RacingNumber' not in list(drv_info.values())[0]:
